@@ -1,9 +1,10 @@
-from typing import Any
+from typing import Any, Dict, Union
 
 import requests
 
 from graphql_requests.client.base import GraphQLBaseClient
 from graphql_requests.errors import GraphQLError
+from graphql_requests.utils import dict_keys_to_snake_case_recursively
 
 
 class GraphQLClient(GraphQLBaseClient):
@@ -13,14 +14,15 @@ class GraphQLClient(GraphQLBaseClient):
 
     def send(
         self,
-        url: str | None = None,
+        url: Union[str, None] = None,
         *,
         query: str,
         operation_name: str = None,
-        variables: str | dict[str, Any] = None,
-        headers: dict[str, Any] | None = None,
-        cookies: dict[str, Any] | None = None,
-    ) -> dict[str, Any]:
+        variables: Union[str, Dict[str, Any]] = None,
+        headers: Union[Dict[str, Any], None] = None,
+        cookies: Union[Dict[str, Any], None] = None,
+        auto_snake_case: Union[bool, None] = True,
+    ) -> Dict[str, Any]:
         """
         Send request to outer Graphql service and return received data
         """
@@ -31,6 +33,7 @@ class GraphQLClient(GraphQLBaseClient):
         headers.update(self._headers or {})
         cookies.update(self._cookies or {})
 
+        # concatenation `_base_url` (that initialized with client) with arg `url`
         if url is not None:
             url = self._base_url.rstrip("/") + "/" + url.lstrip("/")
         else:
@@ -49,7 +52,13 @@ class GraphQLClient(GraphQLBaseClient):
         )
         response_data = response.json()
 
-        if errors := response_data.get("errors"):
+        errors = response_data.get("errors")
+        if errors:
             raise GraphQLError(errors=errors)
 
+        if auto_snake_case:
+            return dict_keys_to_snake_case_recursively(
+                response_data["data"], snake_case_serializer=self._snake_case_serializer
+            )
+
         return response_data["data"]
