@@ -1,7 +1,10 @@
+from typing import Dict, List
+
+
 class GraphQLError(Exception):
     """Base exception for GraphQL clients."""
 
-    def __init__(self, errors: list[dict]) -> None:
+    def __init__(self, errors: List[Dict]) -> None:
         message = "\n".join(
             error.get("message") or "\n".join(error.get("messages")) for error in errors
         )
